### Directions

_Issue tracker is for actionable bug reports, issues with the code and feature requests._
_Remove this section and everything on and above this line._

### Bug reports

__Steps to reproduce:__

1. Example code that produces error.
2. Stack trace or error messages.

__Expected behaviour:__ [What was expected to happen.]

__Actual behaviour:__ [What actually happened.]

__Additional info:__ [Include version of ``libssh2`` and any other relevant information.]
